# Text Signals API

::: veridex.text.perplexity.PerplexitySignal
::: veridex.text.entropy.ZlibEntropySignal
::: veridex.text.binoculars.BinocularsSignal
::: veridex.text.detectgpt.DetectGPTSignal
::: veridex.text.tdetect.TDetectSignal
::: veridex.text.human_ood.HumanOODSignal
